about summary refs log tree commit diff
path: root/compiler/rustc_middle/src
diff options
context:
space:
mode:
authorYuki Okushi <yuki.okushi@huawei.com>2021-06-24 14:21:50 +0900
committerYuki Okushi <yuki.okushi@huawei.com>2021-06-24 14:21:50 +0900
commit462c74007eea1b71a62aa5565352e82ef481a129 (patch)
treeac237c3e7b1d80dc4ccd84273ba38d9f638defd2 /compiler/rustc_middle/src
parenta141d2961289774f15ed884a52cd03c7d096aac5 (diff)
downloadrust-462c74007eea1b71a62aa5565352e82ef481a129.tar.gz
rust-462c74007eea1b71a62aa5565352e82ef481a129.zip
Rename function name in comments
Diffstat (limited to 'compiler/rustc_middle/src')
-rw-r--r--compiler/rustc_middle/src/ty/context.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/compiler/rustc_middle/src/ty/context.rs b/compiler/rustc_middle/src/ty/context.rs
index bf5176f6585..1988bc17376 100644
--- a/compiler/rustc_middle/src/ty/context.rs
+++ b/compiler/rustc_middle/src/ty/context.rs
@@ -1499,12 +1499,12 @@ impl<'tcx> TyCtxt<'tcx> {
     }
 
     pub fn return_type_impl_trait(self, scope_def_id: LocalDefId) -> Option<(Ty<'tcx>, Span)> {
         // HACK: `type_of_def_id()` will fail on these (#55796), so return `None`.
         let hir_id = self.hir().local_def_id_to_hir_id(scope_def_id);
         match self.hir().get(hir_id) {
             Node::Item(item) => {
                 match item.kind {
-                    ItemKind::Fn(..) => { /* `type_of_def_id()` will work */ }
+                    ItemKind::Fn(..) => { /* `type_of()` will work */ }
                     _ => {
                         return None;
                     }
@@ -1516,7 +1516,7 @@ impl<'tcx> TyCtxt<'tcx> {
                     return None;
                 }
             }
-            _ => { /* `type_of_def_id()` will work or panic */ }
+            _ => { /* `type_of()` will work or panic */ }
         }
 
         let ret_ty = self.type_of(scope_def_id);
@@ -1499,12 +1499,12 @@ impl<'tcx> TyCtxt<'tcx> {
 
     pub fn return_type_impl_trait(self, scope_def_id: LocalDefId) -> Option<(Ty<'tcx>, Span)> {
-        // HACK: `type_of_def_id()` will fail on these (#55796), so return `None`.
+        // HACK: `type_of()` will fail on these (#55796), so return `None`.
         let hir_id = self.hir().local_def_id_to_hir_id(scope_def_id);
         match self.hir().get(hir_id) {